@@ -136,7 +136,7 @@ reconverge_type = "results"
 
 % autoclass -predict data/rna/rnac-predict.db2 data/rna/rnac.results-bin data/rna/rnac.search data/rna/rnac.r-params
 
-"try_fn_type = "converge_search_3" & rel_delta_range = 0.0025 & n_average = 3"
+try_fn_type = "converge_search_3" & rel_delta_range = 0.0025 & n_average = 3
 It has 5 CLASSES with WEIGHTS 22 20 11 8 7
 ------------------  SUMMARY OF 10 BEST RESULTS  ------------------
 PROBABILITY: exp(-2270.933) N_CLASSES:  5 FOUND ON TRY:   3 *SAVED*
@@ -144,15 +144,15 @@ PROBABILITY: exp(-2297.160) N_CLASSES:  7 FOUND ON TRY:   4 *SAVED*
 PROBABILITY: exp(-2317.474) N_CLASSES:  3 FOUND ON TRY:   2
 PROBABILITY: exp(-2350.139) N_CLASSES:  2 FOUND ON TRY:   1
 
-"try_fn_type = "converge_search_3" & rel_delta_range = 0.05 & n_average = 3"
+try_fn_type = "converge_search_3" & rel_delta_range = 0.05 & n_average = 3
 It has 5 CLASSES with WEIGHTS 22 20 11 8 7
 ------------------  SUMMARY OF 10 BEST RESULTS  ------------------
-PROBABILITY: exp(-2270.936) N_CLASSES:  5 FOUND ON TRY:   3 *SAVED*
+PROBABILITY: exp(-2270.935) N_CLASSES:  5 FOUND ON TRY:   3 *SAVED*
 PROBABILITY: exp(-2297.157) N_CLASSES:  7 FOUND ON TRY:   4 *SAVED*
 PROBABILITY: exp(-2321.813) N_CLASSES:  3 FOUND ON TRY:   2
 PROBABILITY: exp(-2350.340) N_CLASSES:  2 FOUND ON TRY:   1
 
-"try_fn_type = "converge_search_4" & cs4_delta_range = 0.0025 & sigma_beta_n_values = 6"
+try_fn_type = "converge_search_4" & cs4_delta_range = 0.0025 & sigma_beta_n_values = 6
 It has 5 CLASSES with WEIGHTS 22 20 11 8 7
 ------------------  SUMMARY OF 10 BEST RESULTS  ------------------
 PROBABILITY: exp(-2270.932) N_CLASSES:  5 FOUND ON TRY:   3 *SAVED*
@@ -172,7 +172,7 @@ PROBABILITY: exp(-2350.139) N_CLASSES:  2 FOUND ON TRY:   1
 
 % autoclass -predict data/rna/rnac-location-predict.db2 data/rna/rnac-location.results-bin data/rna/rnac-location.search data/rna/rnac-location.r-params
 
-"try_fn_type = "converge_search_3" & rel_delta_range = 0.0025 & n_average = 3"
+try_fn_type = "converge_search_3" & rel_delta_range = 0.0025 & n_average = 3
 It has 5 CLASSES with WEIGHTS 23 16 11 10 8
 ------------------  SUMMARY OF 10 BEST RESULTS  ------------------
 PROBABILITY: exp(-2514.293) N_CLASSES:  5 FOUND ON TRY:   3 *SAVED*
@@ -180,7 +180,7 @@ PROBABILITY: exp(-2532.702) N_CLASSES:  7 FOUND ON TRY:   4 *SAVED*
 PROBABILITY: exp(-2546.108) N_CLASSES:  3 FOUND ON TRY:   2
 PROBABILITY: exp(-2559.346) N_CLASSES:  2 FOUND ON TRY:   1
 
-"try_fn_type = "converge_search_3" & rel_delta_range = 0.05 & n_average = 3"
+try_fn_type = "converge_search_3" & rel_delta_range = 0.05 & n_average = 3
 It has 5 CLASSES with WEIGHTS 23 16 11 10 8
 ------------------  SUMMARY OF 10 BEST RESULTS  ------------------
 PROBABILITY: exp(-2514.343) N_CLASSES:  5 FOUND ON TRY:   3 *SAVED*
@@ -188,7 +188,7 @@ PROBABILITY: exp(-2532.458) N_CLASSES:  7 FOUND ON TRY:   4 *SAVED*
 PROBABILITY: exp(-2546.141) N_CLASSES:  3 FOUND ON TRY:   2
 PROBABILITY: exp(-2559.150) N_CLASSES:  2 FOUND ON TRY:   1
 
-"try_fn_type = "converge_search_4" & cs4_delta_range = 0.0025 & sigma_beta_n_values = 6"
+try_fn_type = "converge_search_4" & cs4_delta_range = 0.0025 & sigma_beta_n_values = 6
 It has 5 CLASSES with WEIGHTS 23 16 11 10 8
 ------------------  SUMMARY OF 10 BEST RESULTS  ------------------
 PROBABILITY: exp(-2514.293) N_CLASSES:  5 FOUND ON TRY:   3 *SAVED*
@@ -208,7 +208,7 @@ PROBABILITY: exp(-2559.346) N_CLASSES:  2 FOUND ON TRY:   1
 
 % autoclass -predict data/rna/rnac-unk-predict.db2 data/rna/rnac-unk.results-bin data/rna/rnac-unk.search data/rna/rnac-unk.r-params
 
-"try_fn_type = "converge_search_3" & rel_delta_range = 0.0025 & n_average = 3"
+try_fn_type = "converge_search_3" & rel_delta_range = 0.0025 & n_average = 3
 It has 5 CLASSES with WEIGHTS 22 21 10 8 7
 ------------------  SUMMARY OF 10 BEST RESULTS  ------------------
 PROBABILITY: exp(-2315.537) N_CLASSES:  5 FOUND ON TRY:   3 *SAVED*
@@ -216,7 +216,7 @@ PROBABILITY: exp(-2343.858) N_CLASSES:  7 FOUND ON TRY:   4 *SAVED*
 PROBABILITY: exp(-2345.158) N_CLASSES:  3 FOUND ON TRY:   2
 PROBABILITY: exp(-2359.724) N_CLASSES:  2 FOUND ON TRY:   1
 
-"try_fn_type = "converge_search_3" & rel_delta_range = 0.05 & n_average = 3"
+try_fn_type = "converge_search_3" & rel_delta_range = 0.05 & n_average = 3
 It has 5 CLASSES with WEIGHTS 22 21 10 8 7
 ------------------  SUMMARY OF 10 BEST RESULTS  ------------------
 PROBABILITY: exp(-2315.332) N_CLASSES:  5 FOUND ON TRY:   3 *SAVED*
@@ -224,7 +224,7 @@ PROBABILITY: exp(-2343.914) N_CLASSES:  7 FOUND ON TRY:   4 *SAVED*
 PROBABILITY: exp(-2345.153) N_CLASSES:  3 FOUND ON TRY:   2
 PROBABILITY: exp(-2359.718) N_CLASSES:  2 FOUND ON TRY:   1
 
-"try_fn_type = "converge_search_4" & cs4_delta_range = 0.0025 & sigma_beta_n_values = 6"
+try_fn_type = "converge_search_4" & cs4_delta_range = 0.0025 & sigma_beta_n_values = 6
 It has 5 CLASSES with WEIGHTS 22 21 10 8 7
 ------------------  SUMMARY OF 10 BEST RESULTS  ------------------
 PROBABILITY: exp(-2315.537) N_CLASSES:  5 FOUND ON TRY:   3 *SAVED*
@@ -243,7 +243,7 @@ PROBABILITY: exp(-2359.724) N_CLASSES:  2 FOUND ON TRY:   1
 
 % autoclass -predict data/soybean/soyc-predict.db2 data/soybean/soyc.results-bin data/soybean/soyc.search data/soybean/soyc.r-params
 
-"try_fn_type = "converge_search_3" & rel_delta_range = 0.0025 & n_average = 3"
+try_fn_type = "converge_search_3" & rel_delta_range = 0.0025 & n_average = 3
 It has 4 CLASSES with WEIGHTS 17 10 10 10
 ------------------  SUMMARY OF 10 BEST RESULTS  ------------------
 PROBABILITY: exp(-645.604) N_CLASSES:  4 FOUND ON TRY:   3 *SAVED*
@@ -251,7 +251,7 @@ PROBABILITY: exp(-660.007) N_CLASSES:  5 FOUND ON TRY:   4 *SAVED*
 PROBABILITY: exp(-710.824) N_CLASSES:  3 FOUND ON TRY:   2
 PROBABILITY: exp(-727.858) N_CLASSES:  2 FOUND ON TRY:   1
 
-"try_fn_type = "converge_search_3" & rel_delta_range = 0.05 & n_average = 3"
+try_fn_type = "converge_search_3" & rel_delta_range = 0.05 & n_average = 3
 It has 4 CLASSES with WEIGHTS 17 10 10 10
 ------------------  SUMMARY OF 10 BEST RESULTS  ------------------
 PROBABILITY: exp(-645.604) N_CLASSES:  4 FOUND ON TRY:   3 *SAVED*
@@ -259,7 +259,7 @@ PROBABILITY: exp(-660.010) N_CLASSES:  5 FOUND ON TRY:   4 *SAVED*
 PROBABILITY: exp(-710.824) N_CLASSES:  3 FOUND ON TRY:   2
 PROBABILITY: exp(-727.858) N_CLASSES:  2 FOUND ON TRY:   1
 
-"try_fn_type = "converge_search_4" & cs4_delta_range = 0.0025 & sigma_beta_n_values = 6"
+try_fn_type = "converge_search_4" & cs4_delta_range = 0.0025 & sigma_beta_n_values = 6
 It has 4 CLASSES with WEIGHTS 17 10 10 10
 ------------------  SUMMARY OF 10 BEST RESULTS  ------------------
 PROBABILITY: exp(-645.604) N_CLASSES:  4 FOUND ON TRY:   3 *SAVED*
@@ -278,30 +278,30 @@ PROBABILITY: exp(-727.858) N_CLASSES:  2 FOUND ON TRY:   1
 
 % autoclass -predict data/3-dim/3-dimc-predict.db2 data/3-dim/3-dimc.results-bin data/3-dim/3-dimc.search data/3-dim/3-dimc.r-params
 
-"try_fn_type = "converge_search_3" & rel_delta_range = 0.0025 & n_average = 3"
+try_fn_type = "converge_search_3" & rel_delta_range = 0.0025 & n_average = 3
 It has 2 CLASSES with WEIGHTS 58 42
 ------------------  SUMMARY OF 10 BEST RESULTS  ------------------
-PROBABILITY: exp(-4255.624) N_CLASSES:  2 FOUND ON TRY:   4 *SAVED*
+PROBABILITY: exp(-4255.623) N_CLASSES:  2 FOUND ON TRY:   4 *SAVED*
 PROBABILITY: exp(-4257.323) N_CLASSES:  2 FOUND ON TRY:   2 *SAVED*
 PROBABILITY: exp(-4257.496) N_CLASSES:  2 FOUND ON TRY:   1
 PROBABILITY: exp(-4257.508) N_CLASSES:  2 FOUND ON TRY:   3
 
-"try_fn_type = "converge_search_3" & rel_delta_range = 0.05 & n_average = 3"
+try_fn_type = "converge_search_3" & rel_delta_range = 0.05 & n_average = 3
 It has 2 CLASSES with WEIGHTS 50 50
 ------------------  SUMMARY OF 10 BEST RESULTS  ------------------
-PROBABILITY: exp(-4259.770) N_CLASSES:  2 FOUND ON TRY:   1 *SAVED*
+PROBABILITY: exp(-4259.769) N_CLASSES:  2 FOUND ON TRY:   1 *SAVED*
 PROBABILITY: exp(-4270.297) N_CLASSES:  3 FOUND ON TRY:   3 *SAVED*
-PROBABILITY: exp(-4272.344) N_CLASSES:  3 FOUND ON TRY:   4
+PROBABILITY: exp(-4272.345) N_CLASSES:  3 FOUND ON TRY:   4
 PROBABILITY: exp(-4274.939) N_CLASSES:  3 FOUND ON TRY:   2
 
-"try_fn_type = "converge_search_4" & cs4_delta_range = 0.0025 & sigma_beta_n_values = 6"
+try_fn_type = "converge_search_4" & cs4_delta_range = 0.0025 & sigma_beta_n_values = 6
 It has 2 CLASSES with WEIGHTS 58 42
 ------------------  SUMMARY OF 10 BEST RESULTS  ------------------
-PROBABILITY: exp(-4255.619) N_CLASSES:  2 FOUND ON TRY:   4 *SAVED*
+PROBABILITY: exp(-4255.622) N_CLASSES:  2 FOUND ON TRY:   4 *SAVED*
 PROBABILITY: exp(-4257.310) N_CLASSES:  2 FOUND ON TRY:   2 *SAVED*
 PROBABILITY: exp(-4257.496) N_CLASSES:  2 FOUND ON TRY:   1
 PROBABILITY: exp(-4257.508) N_CLASSES:  2 FOUND ON TRY:   3
-
+autoclass -reports data/3-dim/3-dimc.results-bin data/3-dim/3-dimc.search data/3-dim/3-dimc.r-params
 
 ;;;-------------------------------------------------------------
 ;;; MODEL: MULTI-NORMAL-CN, START-FN: BLOCK-SET-CLSF, - GLASS == 
@@ -313,27 +313,27 @@ PROBABILITY: exp(-4257.508) N_CLASSES:  2 FOUND ON TRY:   3
 
 % autoclass -predict data/glass/glassc-predict.db2 data/glass/glassc.results-bin data/glass/glassc.search data/glass/glassc.r-params
 
-"try_fn_type = "converge_search_3" & rel_delta_range = 0.0025 & n_average = 3"
+try_fn_type = "converge_search_3" & rel_delta_range = 0.0025 & n_average = 3
 It has 5 CLASSES with WEIGHTS 97 46 35 19 17
 ------------------  SUMMARY OF 10 BEST RESULTS  ------------------
 PROBABILITY  exp(-10897.738) N_CLASSES   5 FOUND ON TRY    3 *SAVED*
 PROBABILITY  exp(-11187.745) N_CLASSES   7 FOUND ON TRY    4 *SAVED*
-PROBABILITY  exp(-11229.517) N_CLASSES   3 FOUND ON TRY    2
+PROBABILITY  exp(-11229.516) N_CLASSES   3 FOUND ON TRY    2
 PROBABILITY  exp(-11236.431) N_CLASSES   2 FOUND ON TRY    1
 
-"try_fn_type = "converge_search_3" & rel_delta_range = 0.05 & n_average = 3"
+try_fn_type = "converge_search_3" & rel_delta_range = 0.05 & n_average = 3
 It has 5 CLASSES with WEIGHTS 100 43 35 19 17
 ------------------  SUMMARY OF 10 BEST RESULTS  ------------------  
-PROBABILITY  exp(-10907.361) N_CLASSES   5 FOUND ON TRY    3 *SAVED*
-PROBABILITY  exp(-11187.750) N_CLASSES   7 FOUND ON TRY    4 *SAVED*
-PROBABILITY  exp(-11229.555) N_CLASSES   3 FOUND ON TRY    2
-PROBABILITY  exp(-11236.419) N_CLASSES   2 FOUND ON TRY    1
+PROBABILITY  exp(-10907.367) N_CLASSES   5 FOUND ON TRY    3 *SAVED*
+PROBABILITY  exp(-11187.751) N_CLASSES   7 FOUND ON TRY    4 *SAVED*
+PROBABILITY  exp(-11229.554) N_CLASSES   3 FOUND ON TRY    2
+PROBABILITY  exp(-11236.418) N_CLASSES   2 FOUND ON TRY    1
 
-"try_fn_type = "converge_search_4" & cs4_delta_range = 0.0025 & sigma_beta_n_values = 6"
+try_fn_type = "converge_search_4" & cs4_delta_range = 0.0025 & sigma_beta_n_values = 6
 It has 5 CLASSES with WEIGHTS 97 46 35 19 17
 ------------------  SUMMARY OF 10 BEST RESULTS  ------------------
 PROBABILITY  exp(-10897.738) N_CLASSES   5 FOUND ON TRY    3 *SAVED*
-PROBABILITY  exp(-11187.746) N_CLASSES   7 FOUND ON TRY    4 *SAVED*
+PROBABILITY  exp(-11187.745) N_CLASSES   7 FOUND ON TRY    4 *SAVED*
 PROBABILITY  exp(-11229.516) N_CLASSES   3 FOUND ON TRY    2
 PROBABILITY  exp(-11236.432) N_CLASSES   2 FOUND ON TRY    1
 
@@ -346,29 +346,29 @@ PROBABILITY  exp(-11236.432) N_CLASSES   2 FOUND ON TRY    1
 
 % autoclass -predict data/autos/imports-85-predict.db2 data/autos/imports-85.results-bin data/autos/imports-85.search data/autos/imports-85.r-params
 
-"try_fn_type = "converge_search_3" & rel_delta_range = 0.0025 & n_average = 3"
+try_fn_type = "converge_search_3" & rel_delta_range = 0.0025 & n_average = 3
 It has 7 CLASSES with WEIGHTS 50 46 37 31 18 13 11
 ------------------  SUMMARY OF 10 BEST RESULTS  ------------------
 PROBABILITY: exp(-16453.536) N_CLASSES:  7 FOUND ON TRY:   4 *SAVED*
 PROBABILITY: exp(-16654.238) N_CLASSES:  5 FOUND ON TRY:   3 *SAVED*
-PROBABILITY: exp(-16816.657) N_CLASSES:  3 FOUND ON TRY:   2
-PROBABILITY: exp(-17041.866) N_CLASSES:  2 FOUND ON TRY:   1
+PROBABILITY: exp(-16816.658) N_CLASSES:  3 FOUND ON TRY:   2
+PROBABILITY: exp(-17041.867) N_CLASSES:  2 FOUND ON TRY:   1
 
-"try_fn_type = "converge_search_3" & rel_delta_range = 0.05 & n_average = 3"
+try_fn_type = "converge_search_3" & rel_delta_range = 0.05 & n_average = 3
 It has 7 CLASSES with WEIGHTS 50 46 40 28 18 13 11
 ------------------  SUMMARY OF 10 BEST RESULTS  ------------------
-PROBABILITY: exp(-16464.987) N_CLASSES:  7 FOUND ON TRY:   4 *SAVED*
-PROBABILITY: exp(-16674.827) N_CLASSES:  5 FOUND ON TRY:   3 *SAVED*
-PROBABILITY: exp(-16816.728) N_CLASSES:  3 FOUND ON TRY:   2
-PROBABILITY: exp(-17042.459) N_CLASSES:  2 FOUND ON TRY:   1
+PROBABILITY: exp(-16464.989) N_CLASSES:  7 FOUND ON TRY:   4 *SAVED*
+PROBABILITY: exp(-16674.829) N_CLASSES:  5 FOUND ON TRY:   3 *SAVED*
+PROBABILITY: exp(-16816.729) N_CLASSES:  3 FOUND ON TRY:   2
+PROBABILITY: exp(-17042.456) N_CLASSES:  2 FOUND ON TRY:   1
 
-"try_fn_type = "converge_search_4" & cs4_delta_range = 0.0025 & sigma_beta_n_values = 6"
+try_fn_type = "converge_search_4" & cs4_delta_range = 0.0025 & sigma_beta_n_values = 6
 It has 7 CLASSES with WEIGHTS 50 46 37 31 18 13 11
 ------------------  SUMMARY OF 10 BEST RESULTS  ------------------
 PROBABILITY: exp(-16453.532) N_CLASSES:  7 FOUND ON TRY:   4 *SAVED*
 PROBABILITY: exp(-16654.237) N_CLASSES:  5 FOUND ON TRY:   3 *SAVED*
-PROBABILITY: exp(-16816.656) N_CLASSES:  3 FOUND ON TRY:   2
-PROBABILITY: exp(-17041.863) N_CLASSES:  2 FOUND ON TRY:   1
+PROBABILITY: exp(-16816.658) N_CLASSES:  3 FOUND ON TRY:   2
+PROBABILITY: exp(-17041.867) N_CLASSES:  2 FOUND ON TRY:   1
 
 
 ;;;-------------------------------------------------------------
