@@ -889,6 +889,7 @@ void process_attribute_definitions( database_DS d_base, FILE *header_file_fp,
     att_info[i] = d_base->att_info[i] = NULL;
 
   for (i=0; i<n_atts; i++) {
+
     if ((tokens = get_line_tokens(header_file_fp, (int) separator_char, n_comment_chars,
                                comment_chars, first_read, &num_tokens)) == NULL) {
       break;
@@ -1643,13 +1644,15 @@ char **get_line_tokens( FILE *stream, int separator_char, int n_comment_chars,
     *instance_length_ptr = 0;
     strcpy(form, "");
     if (read_line( datum_string, VERY_LONG_STRING_LENGTH, stream) == TRUE) {
+      /* fprintf( stderr, "datum_string1: '%s'\n", datum_string); */
       while ((first_read == TRUE) &&
              (datum_string_first_char = (int) datum_string[0]) &&
              ((datum_string_first_char == '#') || (datum_string_first_char == '!') ||
               (datum_string_first_char == ';') || (datum_string_first_char == ' ') ||
-              (datum_string_first_char == '\n')))
+              (datum_string_first_char == '\n'))) {
         read_line( datum_string, VERY_LONG_STRING_LENGTH, stream);
-
+        /* fprintf( stderr, "datum_stringn: '%s'\n", datum_string); */
+      }
       position = read_from_string( datum_string, form, VERY_LONG_TOKEN_LENGTH,
                                   separator_char, n_comment_chars, comment_chars,
                                   position);
@@ -1671,7 +1674,7 @@ char **get_line_tokens( FILE *stream, int separator_char, int n_comment_chars,
         /* fprintf( stderr, "formn: %s\n", form); */
       }
       *instance_length_ptr = length;
-      /* printf("instance_length = %d\n", length);   */
+      /* fprintf( stderr, "instance_length = %d\n", length); */
       if ((eqstring(form, "comment") == FALSE) && (eqstring(form, "eof") == FALSE) &&
           (length <= 1)) {
         fprintf(stderr,
@@ -1874,7 +1877,7 @@ void find_real_stats( database_DS d_base, int n_att, FILE *log_file_fp, FILE *st
     strcpy(att->warnings_and_errors->single_valued_warning, "true");
   }
   else if ((error != 0.0) && (error > (.1 * (mx - mn)))) {
-    percent_error = round( (double) (100.0 * (error / (mx - mn))));
+    percent_error = iround( (double) (100.0 * (error / (mx - mn))));
     safe_sprintf( str, sizeof( str), caller,
                  "ADVISORY[2]: attribute #%d: \"%s\", the error %f is %d%% \n"
                  "             of the range %f.\n",
@@ -2022,7 +2025,7 @@ void output_att_statistics( database_DS d_base, FILE *log_file_fp, FILE *stream)
   }
   if ((stats_to_output_p == TRUE) && (log_file_fp != NULL)) {
     to_screen_and_log_file
-      ("ADVISORY[1]: real statistics [ min < (mean : variance) < max ] built \n"
+      ("ADVISORY[1]: real statistics [ min < (mean : std dev) < max ] built \n"
        "             from input data --\n",
        log_file_fp, stream, TRUE);
     for (n_att=0; n_att<n_atts; n_att++) 
@@ -2060,9 +2063,9 @@ void output_real_att_statistics( database_DS d_base, int n_att, FILE *log_file_f
                    "   Attribute #%d, \"%s\":\n      [", n_att, att->dscrp);
       to_screen_and_log_file( str, log_file_fp, stream, TRUE);
       safe_sprintf( str, sizeof( str), caller,
-                   " %11.4e < (%11.4e : %10.4e) < %11.4e ]\n",
-                   r_statistics->mn, r_statistics->mean, r_statistics->var,
-                   r_statistics->mx);
+                    " %11.4e < (%11.4e : %10.4e) < %11.4e ]\n",
+                    r_statistics->mn, r_statistics->mean, sqrt(r_statistics->var),
+                    r_statistics->mx);
       to_screen_and_log_file( str, log_file_fp, stream, TRUE);
       if (r_statistics->var > INFINITY) {
         fprintf( stderr, "\nERROR: (output_real_att_statistics) attribute #%d: \"%s\", \n"
