@@ -595,6 +595,9 @@ clsf_DS load_clsf( FILE *results_file_fp, int expand_p, int want_wts_p, int upda
                              ((expand_list[0] != END_OF_INT_LIST) &&
                               (member_int_list( clsf_index+1, expand_list) == TRUE)))) {
       expand_clsf( clsf, want_wts_p, update_wts_p);
+      if(first_clsf && clsf && (first_clsf->models != clsf->models)) {
+	first_clsf->models = clsf->models;
+      }
  
       /* fprintf( stderr, "clsf index %d expanded\n", clsf_index); */
     }
