@@ -90,7 +90,7 @@ static priors_DS build_sn_cm_priors( database_DS data_base, att_DS att)
                 (float) sqrt( ABSOLUTE_MIN_CLASS_WT)) * sigma_min);
    priors->mean_var = square(priors->mean_sigma);
    priors->minus_log_log_sigmas_ratio =
-     - (float) log( max( log( 1.0 / (1.0 - SINGLE_FLOAT_EPSILON)),
+     - (float) safe_log( max( safe_log( 1.0 / (1.0 - SINGLE_FLOAT_EPSILON)),
                         max( safe_log( (double) (priors->sigma_max / priors->sigma_min)),
                             LEAST_POSITIVE_SHORT_FLOAT)));
    priors->minus_log_mean_sigma = - (float) safe_log( (double) priors->mean_sigma);
@@ -171,7 +171,7 @@ void single_normal_cm_model_term_builder( model_DS model, term_DS term, int n_te
 
    tparm->log_delta = log_delta_div_root_2pi;
    tparm->log_att_delta = log_att_delta;
-   tparm->log_pi = (float) (-1.0 * log( M_PI));
+   tparm->log_pi = (float) (-1.0 * safe_log( M_PI));
 
    sn = &(tparm->ptype.sn_cm);
 
@@ -185,7 +185,7 @@ void single_normal_cm_model_term_builder( model_DS model, term_DS term, int n_te
    sn->prior_mean_mean = prior_set->mean_mean;
    sn->prior_mean_var = prior_set->mean_var; 
    sn->prior_mean_sigma = prior_set->mean_sigma;
-   sn->prior_sigmas_term = (-1.5 * (float) log( 2.0)) +
+   sn->prior_sigmas_term = (-1.5 * (float) safe_log( 2.0)) +
       prior_set->minus_log_log_sigmas_ratio +
       (-1.0 * (float) safe_log((double) prior_set->mean_sigma));
 
@@ -243,7 +243,7 @@ double single_normal_cm_update_l_approx( tparm_DS tparm)
   t1 = -0.5 * w_j_known * ((sn->weighted_var + t1) / sn->variance);
   t2 = ((w_j - w_j_known) * sn->unknown_log_prob) +
     (w_j_known * sn->known_log_prob) +
-      (w_j_known * (log_delta - (float) log((double) sn->sigma))) + t1;
+      (w_j_known * (log_delta - (float) safe_log((double) sn->sigma))) + t1;
   return (t2);
 }
 
@@ -288,9 +288,9 @@ double single_normal_cm_update_m_approx( tparm_DS tparm)
         log_gamma( (double) (0.5 * (t_w_j_known - 1.0)), FALSE) + (double) t1 +
 	  (double) (t_w_j_known * log_att_delta) +
             (-0.5 * (double) t_w_j_known *
-	     log( M_PI * (double) t_w_j_known)) +
+	     safe_log( M_PI * (double) t_w_j_known)) +
                (-0.5 * (double) (t_w_j_known - 1.0) *
-                log((double) max( LEAST_POSITIVE_SINGLE_FLOAT, sn->weighted_var))) +
+                safe_log((double) max( LEAST_POSITIVE_SINGLE_FLOAT, sn->weighted_var))) +
                   prior_sigmas_term;
   return( ((double) t2) * temp);
 }
@@ -354,9 +354,9 @@ void single_normal_cm_update_params( tparm_DS tparm, int known_parms_p)
     prob_known = max(LEAST_POSITIVE_SINGLE_FLOAT,
                      (sn_cm->known_wt + prior_known_prior) / class_wt_1);
     sn_cm->known_prob = prob_known;
-    sn_cm->known_log_prob = (float) log((double) prob_known);
+    sn_cm->known_log_prob = (float) safe_log((double) prob_known);
     sn_cm->unknown_log_prob =
-      (float) log((double) max( LEAST_POSITIVE_SINGLE_FLOAT,
+      (float) safe_log((double) max( LEAST_POSITIVE_SINGLE_FLOAT,
                                1.0 - prob_known));
     var_ratio = sn_cm->weighted_var / (class_wt_1 * prior_mean_var);
     sn_cm->mean = (sn_cm->weighted_mean * (1.0 - var_ratio)) +
@@ -364,7 +364,7 @@ void single_normal_cm_update_params( tparm_DS tparm, int known_parms_p)
     sn_cm->variance = max(sn_cm->weighted_var * (class_wt / class_wt_1),
                           (float) sqrt( LEAST_POSITIVE_SINGLE_FLOAT));
     sn_cm->sigma = (float) sqrt((double) sn_cm->variance);
-    sn_cm->log_variance = (float) log((double) sn_cm->variance);
+    sn_cm->log_variance = (float) safe_log((double) sn_cm->variance);
     sn_cm->log_sigma = 0.5 * sn_cm->log_variance;
     sn_cm->inv_variance = 1.0 / sn_cm->variance;
     sn_cm->ll_min_diff =
