@@ -60,7 +60,7 @@ static priors_DS build_sn_cn_priors( att_DS att)
    sigma_min = SN_CM_SIGMA_SAFETY_FACTOR * att->error;
                                         /* The max sigma for values in range. */
    sigma_max = max(sigma_min, range / 2.0);
-   if (sigma_min == sigma_max) {
+   if (sigma_min == sigma_max) { 
       n = att->warnings_and_errors->num_expander_errors;
       att->warnings_and_errors->num_expander_errors += 1;
       if (n == 0)
@@ -72,7 +72,7 @@ static priors_DS build_sn_cn_priors( att_DS att)
       strcpy(att->warnings_and_errors->model_expander_errors[n],
              "          single_normal_cn is faulty due to large error-to-range\n"
              "          ratio on sigma priors.\n");
-   }
+   } 
    priors = (priors_DS) malloc(sizeof(struct priors));
    priors->sigma_min = sigma_min;
    priors->sigma_max = sigma_max;
@@ -84,7 +84,7 @@ static priors_DS build_sn_cn_priors( att_DS att)
                 (float) sqrt( ABSOLUTE_MIN_CLASS_WT)) * sigma_min);
    priors->mean_var = square(priors->mean_sigma);
    priors->minus_log_log_sigmas_ratio =
-     - (float) log( max( log( 1.0 / (1.0 - SINGLE_FLOAT_EPSILON)),
+     - (float) safe_log( max( safe_log( 1.0 / (1.0 - SINGLE_FLOAT_EPSILON)),
                         max( safe_log((double) (priors->sigma_max / priors->sigma_min)),
                             LEAST_POSITIVE_SHORT_FLOAT)));
    priors->minus_log_mean_sigma = - (float) safe_log( (double) priors->mean_sigma);
@@ -167,7 +167,7 @@ void single_normal_cn_model_term_builder( model_DS model, term_DS term, int n_te
 
    tparm->log_delta = log_delta_div_root_2pi;
    tparm->log_att_delta = log_att_delta;
-   tparm->log_pi = -1.0 * (float) log( M_PI);
+   tparm->log_pi = -1.0 * (float) safe_log( M_PI);
 
    sn = &(tparm->ptype.sn_cn);
 			                            /* Allocate & SET priors. */
@@ -180,7 +180,7 @@ void single_normal_cn_model_term_builder( model_DS model, term_DS term, int n_te
    sn->prior_mean_mean = prior_set->mean_mean;
    sn->prior_mean_var = prior_set->mean_var;
    sn->prior_mean_sigma = prior_set->mean_sigma;
-   sn->prior_sigmas_term = (-1.5 * (float) log( 2.0)) +
+   sn->prior_sigmas_term = (-1.5 * (float) safe_log( 2.0)) +
       prior_set->minus_log_log_sigmas_ratio +
       (-1.0 * (float) safe_log((double) prior_set->mean_sigma));
                                                /* Generate function elements: */
@@ -260,9 +260,9 @@ double single_normal_cn_update_m_approx( tparm_DS tparm)
   t2 =  log_gamma( (double) (0.5 * (w_j - 1.0)), FALSE) + 
          (double) t1 +
          (double) (w_j * log_att_delta) +
-         (-0.5 * (double) w_j * log((double) (M_PI * w_j))) +
+         (-0.5 * (double) w_j * safe_log((double) (M_PI * w_j))) +
          (-0.5 * (double) (w_j - 1.0) *
-          log( (double) max( LEAST_POSITIVE_SINGLE_FLOAT,
+          safe_log( (double) max( LEAST_POSITIVE_SINGLE_FLOAT,
                             sn->weighted_var))) +
          (double) prior_sigmas_term;
   return (t2);
@@ -320,7 +320,7 @@ void single_normal_cn_update_params( tparm_DS tparm, int known_parms_p)
     sn->variance =  max(sn->weighted_var * (class_wt / class_wt_1),
                         (float) sqrt( LEAST_POSITIVE_SINGLE_FLOAT));
     sn->sigma = (float) sqrt((double) sn->variance);
-    sn->log_variance = (float) log((double) sn->variance);
+    sn->log_variance = (float) safe_log((double) sn->variance);
     sn->log_sigma = 0.5 * sn->log_variance;
     sn->inv_variance = 1.0 / sn->variance;
     sn->ll_min_diff =
