@@ -971,7 +971,7 @@ int min_n_peaks( int n_dups,int n_dup_tries)
    float val;
 
    val = (float) n_dup_tries / (float) (1.0 + n_dups);
-   return(round( (double) val));
+   return(iround( (double) val));
 }
 
 
@@ -1025,10 +1025,10 @@ int random_j_from_ln_normal( int n_tries, search_try_DS *tries, int  max_j,
    best = safe_subseq_of_tries(tries, 0, n_best_track, n_tries, &bnum);
    flist_ptr = (float *) malloc(bnum * sizeof(float));
    for (i=0; i<bnum; i++)
-      flist_ptr[i] = (float) log((double) tries[i]->j_in);
+      flist_ptr[i] = (float) safe_log((double) tries[i]->j_in);
    ln_j_avg = (float) average(flist_ptr, bnum);
    ln_j_sigma =
-      (float) within(log((double) (1.0 +
+      (float) within(safe_log((double) (1.0 +
                                    (min_sigma * (float) safe_exp((double) (-1.0 * ln_j_avg))))),
                      sigma(flist_ptr, bnum, (double) ln_j_avg), 10.0);
    free(best);
@@ -1113,7 +1113,7 @@ double approx_inverse_erfc( double area, double z_try)
    double val;
 
    val = ((erfc_poly( z_try) / area) / sqrt( M_PI)) / z_try;
-   return (sqrt( log( val)));
+   return (sqrt( safe_log( val)));
 }
 
 
@@ -1785,7 +1785,7 @@ void describe_clsf( clsf_DS clsf, FILE *stream, FILE *log_file_fp)
    to_screen_and_log_file( str, log_file_fp, stream, TRUE);
    wts = clsf_DS_w_j( clsf);
    for (i=0; i<clsf->n_classes; i++) 
-     temp_num_ptr[i] = round( (double) wts[i]);
+     temp_num_ptr[i] = iround( (double) wts[i]);
    qsort( temp_num_ptr, clsf->n_classes, sizeof(int), comp_func);
    for (i=0; i<clsf->n_classes; i++) {
      sprintf( str, " %d", *(temp_num_ptr + i));
