@@ -7,7 +7,7 @@ of the attributes used mean.
 
 The procedure by which these files were created is described in: 
 
-    scriptc.lisp
+    scriptc.text
 
 A direct dump of the screen from the run is in: 
 
